Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2385)

Unified Diff: chrome/browser/cocoa/extension_installed_bubble_controller.h

Issue 4724005: Add a help bubble pointing to the omnibox when installing an extension with (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: xib Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/cocoa/extension_installed_bubble_controller.h
diff --git a/chrome/browser/cocoa/extension_installed_bubble_controller.h b/chrome/browser/cocoa/extension_installed_bubble_controller.h
index e5f50a3d9a1d9cad667e8958beee697e0f8f8af8..7d0417f10c736776de07115faaaf8895210a992c 100644
--- a/chrome/browser/cocoa/extension_installed_bubble_controller.h
+++ b/chrome/browser/cocoa/extension_installed_bubble_controller.h
@@ -33,8 +33,9 @@ const int kInnerVerticalMargin = 10;
// We use a different kind of notification for each of these extension types.
typedef enum {
kBrowserAction,
- kPageAction,
- kGeneric
+ kGeneric,
+ kOmniboxKeyword,
+ kPageAction
} ExtensionType;
}
@@ -68,7 +69,8 @@ typedef enum {
IBOutlet HoverCloseButton* closeButton_;
IBOutlet NSImageView* iconImage_;
IBOutlet NSTextField* extensionInstalledMsg_;
- IBOutlet NSTextField* pageActionInfoMsg_; // Only shown for page actions.
+ // Only shown for page actions and omnibox keywords.
+ IBOutlet NSTextField* extraInfoMsg_;
IBOutlet NSTextField* extensionInstalledInfoMsg_;
}
@@ -102,7 +104,7 @@ typedef enum {
- (int)calculateWindowHeight;
- (void)setMessageFrames:(int)newWindowHeight;
- (NSRect)getExtensionInstalledMsgFrame;
-- (NSRect)getPageActionInfoMsgFrame;
+- (NSRect)getExtraInfoMsgFrame;
- (NSRect)getExtensionInstalledInfoMsgFrame;
@end // ExtensionInstalledBubbleController(ExposedForTesting)
« no previous file with comments | « chrome/app/nibs/ExtensionInstalledBubble.xib ('k') | chrome/browser/cocoa/extension_installed_bubble_controller.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698